@@ -318,6 +318,15 @@ public class JobSessionNodeImpl {
 			instructionInfo.setCheckSum(result);
 			//整合性チェックするファイルパスを設定
 			instructionInfo.setFilePath(job.getArgument());
+		} else if (instructionInfo.getJobId().endsWith(CreateHulftJob.HULOPLCMD)) {
+			//セッションIDとジョブIDから、セッションジョブを取得
+			JobSessionJobEntity argumentSessionJob = QueryUtil.getJobSessionJobPK(
+					sessionId, jobunitId,
+					job.getArgumentJobId());
+			String result = argumentSessionJob.getResult();
+			
+			// TRIDを指定
+			instructionInfo.setCommand(instructionInfo.getCommand() + " " + result);
 		}
 
 		try {
@@ -448,6 +457,9 @@ public class JobSessionNodeImpl {
 						}else if(info.getCommand().equals(CommandConstant.GET_CHECKSUM)){
 							//チェックサム取得
 							sessionNode.setResult(info.getCheckSum());
+						} else if (CreateHulftJob.isHulftMode() && info.getJobId().endsWith(CreateHulftJob.UTLSEND)) {
+							//TRID取得
+							sessionNode.setResult(info.getMessage());
 						}
 					}else{
 						m_log.debug("endNodeSetStatus() : this messsage is already received. drop message." +
@@ -655,7 +667,7 @@ public class JobSessionNodeImpl {
 	public HashMap<String, List<JobSessionNodeEntityPK>> checkTimeoutAll() throws JobInfoNotFound {
 		EntityManager em = new JpaTransactionManager().getEntityManager();
 		Collection<JobSessionNodeEntity> collection = null;
-		collection = em.createNamedQuery("JobSessionNodeEntity.findByStatus", JobSessionNodeEntity.class)
+		collection = em.createNamedQuery("JobSessionNodeEntity.findByStatusStartIsNull", JobSessionNodeEntity.class)
 				.setParameter("status", StatusConstant.TYPE_RUNNING)
 				.getResultList();
 
