@@ -929,8 +929,8 @@ public class JobControllerBean implements CheckFacility {
 				jtm.commit();
 			}
 			// ジョブの状態が変化した後に、runUnendSessionを実行してもらいたいので、
-			// checkDateをクリアする。
-			JobSessionJobImpl.clearCheckDate(property.getSessionId());
+			// forceCheckのフラグを立てる。
+			JobSessionJobImpl.addForceCheck(property.getSessionId());
 		} catch (HinemosUnknown e) {
 			jtm.rollback();
 			throw e;
