@@ -15,51 +15,42 @@ GNU General Public License for more details.
 
 package com.clustercontrol.poller;
 
-import java.lang.reflect.Constructor;
 import java.util.ArrayList;
+import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Map.Entry;
 import java.util.Set;
 
-import javax.ejb.FinderException;
-import javax.naming.InitialContext;
-import javax.naming.NamingException;
-import javax.rmi.PortableRemoteObject;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.SnmpVersionConstant;
+import com.clustercontrol.commons.util.HinemosProperties;
 import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.plugin.impl.SchedulerPlugin;
+import com.clustercontrol.plugin.impl.SharedTablePlugin;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.SchedulerType;
+import com.clustercontrol.poller.bean.PollerProtocolConstant;
+import com.clustercontrol.poller.impl.SnmpBulkPollerImpl;
+import com.clustercontrol.poller.impl.SnmpPollerImpl;
+import com.clustercontrol.poller.impl.WbemPollerImpl;
+import com.clustercontrol.poller.session.PollingJobBean;
 import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.repository.factory.NodeProperty;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.DataTableNotFoundException;
 import com.clustercontrol.sharedtable.SharedTable;
-import com.clustercontrol.vm.bean.VmMethodTypeConstant;
-import com.clustercontrol.vm.ejb.entity.VmMethodMstLocal;
-import com.clustercontrol.vm.ejb.entity.VmMethodMstPK;
-import com.clustercontrol.vm.ejb.entity.VmMethodMstUtil;
-import com.clustercontrol.vm.VmPollerImplInterface;
-import com.clustercontrol.bean.SnmpVersionConstant;
-import com.clustercontrol.commons.scheduler.TriggerConstant;
-import com.clustercontrol.commons.scheduler.TriggerSchedulerException;
-import com.clustercontrol.commons.scheduler.TriggerSchedulerFactory;
-import com.clustercontrol.commons.util.HinemosProperties;
-import com.clustercontrol.poller.bean.PollerProtocolConstant;
-import com.clustercontrol.poller.ejb.session.PollingJobBean;
-import com.clustercontrol.poller.ejb.session.PollingJobUtil;
-import com.clustercontrol.poller.impl.SnmpBulkPollerImpl;
-import com.clustercontrol.poller.impl.SnmpPollerImpl;
-import com.clustercontrol.poller.impl.WbemPollerImpl;
+import com.clustercontrol.commons.util.ObjectSharingService;
 
 public class PollingController {
 	private static Log m_log = LogFactory.getLog( PollingController.class );
 
 	private Object modifyLock = new Object();
 
-	public final static String SHARED_TABLE_JNDI_NAME = "SharedTable";
 	public final static String POLLER_MANAGER_JNDI_NAME = "PollerManager";
 
 	private final static int RUNNING = 1;
@@ -85,14 +76,14 @@ public class PollingController {
 	// SNMP BULKを利用するフラグ。
 	private static boolean snmpBulkFlag = false;
 	static {
-		String key = "poller.snmp.bulk.flag";
+		String key = "monitor.resource.snmpbulk";
 		try {
 			String str = HinemosProperties.getProperty(key);
 			if (str != null && "true".equals(str)) {
 				snmpBulkFlag = true;
 			}
 		} catch (Exception e) {
-			m_log.warn(key + " is not available. " + e.getMessage());
+			m_log.warn(key + " is not available. " + e.getMessage(), e);
 		}
 	}
 
@@ -103,7 +94,7 @@ public class PollingController {
 			boolean indexCheckFlg,
 			String tableGroup,
 			String tableName)
-	throws NotInitializedException, DataTableNotFoundException{
+					throws NotInitializedException, DataTableNotFoundException{
 		m_pollerGroup = pollerGroup;
 		m_pollerName = pollerName;
 		m_targetFacilityId = targetFacilityId;
@@ -116,18 +107,15 @@ public class PollingController {
 
 		m_status = PollingController.STOPPED;
 
-		try {
-			// 書き込み対象テーブルが存在するか否かを確認する
-			SharedTable sharedTable = lookupSharedTable();
+		// 書き込み対象テーブルが存在するか否かを確認する
+		SharedTable sharedTable = SharedTablePlugin.getSharedTable();
 
-			if(!sharedTable.containsDataTable(tableGroup, tableName)){
-				// テーブルが存在しないため例外を投げる
-				throw new DataTableNotFoundException(tableGroup, tableName);
-			}
-		} catch (NamingException e) {
-			m_log.error("get SharedTable:" + e.getMessage());
-			throw new NotInitializedException(
-					"Table is not initialized. (" + tableName + " in " + tableGroup + " )");
+		if(!sharedTable.containsDataTable(tableGroup, tableName)){
+			// テーブルが存在しないため例外を投げる
+			DataTableNotFoundException e = new DataTableNotFoundException(tableGroup, tableName);
+			m_log.info("PollingController() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
 		}
 	}
 
@@ -144,14 +132,12 @@ public class PollingController {
 		if(interval == -1){
 			try {
 				// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
-				TriggerSchedulerFactory.getScheduler(TriggerConstant.POLLER_INSTANCE_NAME).deleteJob(
-						m_quartzJobName,
-						m_quartzGroupName);
+				SchedulerPlugin.deleteJob(SchedulerType.RAM, m_quartzJobName, m_quartzGroupName);
 
 				// ステータス変更
 				m_status = PollingController.STOPPED;
-			} catch (TriggerSchedulerException e) {
-				m_log.error(e.getMessage(), e);
+			} catch (HinemosUnknown e) {
+				m_log.warn(e.getMessage(), e);
 			}
 			return;
 		}
@@ -170,23 +156,12 @@ public class PollingController {
 
 			String cronString = PollingInterval.parseCronExpression(interval);
 			if(cronString == null){
-				m_log.error("Illegal argument : interval = " + interval);
+				m_log.info("Illegal argument : interval = " + interval);
 			} else {
-				TriggerSchedulerFactory.getScheduler(TriggerConstant.MONITOR_INSTANCE_NAME).scheduleEjbLocalInvokerJobWithCronTrigger(
-						m_quartzJobName,
-						m_quartzGroupName,
-						PollingJobUtil.getLocalHome(),
-						PollingJobBean.METHOD_NAME,
-						jdArgs,
-						jdArgsType,
-						null,
-						true,
-						true,
-						cronString);
+				SchedulerPlugin.scheduleCronJob(SchedulerType.RAM, m_quartzJobName, m_quartzGroupName,
+						new Date(), cronString, true, PollingJobBean.class.getName(), PollingJobBean.METHOD_NAME, jdArgsType, jdArgs);
 			}
-		} catch (TriggerSchedulerException e) {
-			m_log.warn("scheduleJob() : pollerGroup = " + m_pollerGroup + ", pollerName = " + m_pollerName + ", " + e.getMessage(), e);
-		} catch (NamingException e) {
+		} catch (HinemosUnknown e) {
 			m_log.warn("scheduleJob() : pollerGroup = " + m_pollerGroup + ", pollerName = " + m_pollerName + ", " + e.getMessage(), e);
 		}
 	}
@@ -198,36 +173,28 @@ public class PollingController {
 	 * @param collectorName 収集名
 	 * @param interval 収集間隔
 	 * @param maps 収集プロトコルとポーリング対象のマップ
-	 * @throws CollectorAlreadyExistException 既に該当の収集名で収集が開始されている
 	 */
 	public void startPolling(
 			String collectorName,
 			int interval,
-			HashMap<String, List<String>> maps)
-	throws CollectorAlreadyExistException{
+			HashMap<String, List<String>> maps) {
 		m_log.debug("startPolling() collectorName = " + collectorName + ", interval = " + interval);
 
 		synchronized (modifyLock) {
 			// 指定の収集名が既に登録されている場合も、上書きする（ver3.2より）
 			if(m_pollingConfig.containsCollectorName(collectorName)){
 				m_log.debug(collectorName + "is already exist.");
-				//				// 既に収集名が設定されているため例外を投げる
-				//				throw new CollectorAlreadyExistException(collectorName);
 			}
 
 			try {
 				// 書き込み対象テーブルが存在するか否かを確認する
-				SharedTable stable = lookupSharedTable();
+				SharedTable stable = SharedTablePlugin.getSharedTable();
 
 				if(!stable.containsCollectorName(m_tableGroup, m_tableName, collectorName)){
 					// ない場合は新規に作成する
 					stable.registerCollector(m_tableGroup, m_tableName, collectorName, interval);
 				}
 			} catch (DataTableNotFoundException e) {
-				m_log.error(e.getMessage(), e);
-				return;
-			} catch (NamingException e) {
-				m_log.error(e.getMessage(), e);
 				return;
 			}
 
@@ -258,15 +225,12 @@ public class PollingController {
 
 			try {
 				// 書き込み対象テーブルの登録情報を削除する
-				SharedTable stable = lookupSharedTable();
+				SharedTable stable = SharedTable.getInstance();
 
 				stable.unregisterCollector(m_tableGroup, m_tableName, collectorName);
 			} catch (DataTableNotFoundException e) {
 				m_log.warn(e.getMessage(), e);
 				return;
-			} catch (NamingException e) {
-				m_log.error(e.getMessage(), e);
-				return;
 			}
 		}
 	}
@@ -287,15 +251,10 @@ public class PollingController {
 				scheduleJob();
 			}
 
-			try {
-				// 書き込み対象テーブルを削除する
-				SharedTable sharedtable = lookupSharedTable();
-				if(sharedtable != null){
-					sharedtable.removeDataTable(m_tableGroup, m_tableName);
-				}
-			} catch (NamingException e) {
-				m_log.error(e.getMessage(), e);
-				return;
+			// 書き込み対象テーブルを削除する
+			SharedTable sharedtable = SharedTablePlugin.getSharedTable();
+			if(sharedtable != null){
+				sharedtable.removeDataTable(m_tableGroup, m_tableName);
 			}
 		}
 	}
@@ -308,32 +267,23 @@ public class PollingController {
 		m_log.debug("run start : " + m_pollerGroup + "  " + m_pollerName);
 
 		SharedTable sharedTable = null;
-		// 収集値格納用テーブルをルックアップ
-		try {
-			// 共有テーブルをルックアップして取得する
-			sharedTable = lookupSharedTable();
-			if(sharedTable == null){
-				// 書き込み対象テーブルを取得できないため終了する
-				return;
-			}
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
-		}
+		// 共有テーブルを取得する
+		sharedTable = SharedTablePlugin.getSharedTable();
 
 		try {
 
 			Set<String> stCollectorNames =
-				new HashSet<String>(sharedTable.getCollectorNames(m_tableGroup, m_tableName));
+					new HashSet<String>(sharedTable.getCollectorNames(m_tableGroup, m_tableName));
 			for(String collectorName : stCollectorNames){
 				if(m_pollingConfig.containsCollectorName(collectorName)){
 					m_log.debug("run : " + m_pollerGroup + "  " + m_pollerName + " : " + collectorName + " is exist");
 				}else{
-					m_log.warn("run : " + m_pollerGroup + "  " + m_pollerName + " : " + collectorName + " is not exist");
+					m_log.info("run : " + m_pollerGroup + "  " + m_pollerName + " : " + collectorName + " is not exist");
 				}
 			}
 
 			Set<String> pcCollectoName =
-				new HashSet<String>(m_pollingConfig.getCollectorNames());
+					new HashSet<String>(m_pollingConfig.getCollectorNames());
 			pcCollectoName.removeAll(stCollectorNames);
 			synchronized (modifyLock) {
 
@@ -350,7 +300,7 @@ public class PollingController {
 			}
 
 		} catch (DataTableNotFoundException e) {
-			m_log.error(e.getMessage(), e);
+			m_log.warn(e.getMessage(), e);
 			// 書き込み対象テーブルを取得できないため終了する
 			return;
 		}
@@ -360,7 +310,7 @@ public class PollingController {
 		try {
 			holderIntervals = sharedTable.getIntervals(m_tableGroup, m_tableName);
 		} catch (DataTableNotFoundException e) {
-			m_log.error(e.getMessage(), e);
+			m_log.warn(e.getMessage(), e);
 			// 書き込み対象テーブルを取得できないため終了する
 			return;
 		}
@@ -412,18 +362,17 @@ public class PollingController {
 		try {
 			nodeInfo = NodeProperty.getProperty(m_targetFacilityId);
 		} catch (FacilityNotFound e1) {
-			m_log.warn("facility not found 1. FacilityId = " + m_targetFacilityId);
 			// ポーリングは実行しない
 			// 取得値が空のテーブルを作成する
 			dataTable = new DataTable();
 		}
 		if(nodeInfo == null) {
-			m_log.warn("facility not found 2. FacilityId = " + m_targetFacilityId);
+			m_log.info("facility not found 2. FacilityId = " + m_targetFacilityId);
 			// ポーリングは実行しない
 			// 取得値が空のテーブルを作成する
 			dataTable = new DataTable();
 		} else if (nodeInfo.getFacilityId() == null || "".equals(nodeInfo.getFacilityId())){
-			m_log.warn("invalid FacilityId. FacilityId = " + nodeInfo.getFacilityId());
+			m_log.info("invalid FacilityId. FacilityId = " + nodeInfo.getFacilityId());
 			// ポーリングは実行しない
 			// 取得値が空のテーブルを作成する
 			dataTable = new DataTable();
@@ -455,7 +404,7 @@ public class PollingController {
 						dataTable,
 						nodeInfo.getAvailableIpAddress());
 			} catch (DataTableNotFoundException e) {
-				m_log.error(e.getMessage(), e);
+				m_log.warn(e.getMessage(), e);
 			}
 		}
 
@@ -539,102 +488,64 @@ public class PollingController {
 		}
 
 		// *****************************
-		// 仮想化のpollerの設定
-		//   プロトコルがSNMP,WBEM以外の場合(VMware,XENなど)は下記が処理される。
+		// オプションのpollerの設定
+		//	pollingTargetMapのKEYにより識別する
+		//	SNMP	SNMPポーラ(非オプション機能)
+		//	WBEM	WBEMポーラ(非オプション機能)
+		//	VM.		VM管理オプション(VmPollerImplInterface)	(ex. VM.XEN)
+		//	CLOUD.	クラウド管理オプション(ICloudPoller)		(ex. CLOUD.AWS)
 		// *****************************
-		Iterator<String> pollerProtocolItr = pollingTargetMap.keySet().iterator();
-		while (pollerProtocolItr.hasNext()) {
-			String pollerProtocol = pollerProtocolItr.next();
-			m_log.debug("pollerProtocol : " + pollerProtocol);
+		for (Entry<String, List<String>> entry : pollingTargetMap.entrySet()) {
+			String pollerProtocol = entry.getKey();
+			List<String> pollingTarget = entry.getValue();
+			////
+			// 非オプション機能の場合は除く
+			////
 			if (pollerProtocol.equals(PollerProtocolConstant.PROTOCOL_SNMP) ||
 					pollerProtocol.equals(PollerProtocolConstant.PROTOCOL_WBEM)) {
 				continue;
 			}
-			VmMethodMstLocal local = null;
-			try {
-				local = VmMethodMstUtil.getLocalHome().findByPrimaryKey(new VmMethodMstPK(
-						pollerProtocol, VmMethodTypeConstant.POLLERIMPL));
-			} catch (FinderException e) {
-				e.printStackTrace();
-			} catch (NamingException e) {
-				e.printStackTrace();
+			// プロトコルとターゲットの文字列の出力
+			if (m_log.isDebugEnabled()) {
+				m_log.debug("pollerProtocol : " + pollerProtocol);
+				m_log.debug("pollingTarget : " + pollingTarget.toString());
 			}
-			if(local == null){
-				m_log.warn(pollerProtocol + " : Execution Class is not registered. (" +
-						VmMethodTypeConstant.POLLERIMPL +
-				")");
-				continue;
-			}
-
-			// pollerProtocolの実行クラス名をcc_vm_solution_mstから取得。
-			// 存在していない場合、中止。
-			String className = local.getClassName();
-			m_log.debug("action() : className = " + className);
-			if(className == null) {
-				m_log.warn(pollerProtocol + " : Execution Class is not registered.");
-				continue;
-			}
-
-			// コンストラクタの生成
-			// 失敗したら、中止。
-			Constructor pollerConstructor = null;
-			try {
-				pollerConstructor = Class.forName(className).getConstructor();
-			} catch (SecurityException e) {
-				m_log.error(e.getMessage(), e);
-			} catch (NoSuchMethodException e) {
-				m_log.error(e.getMessage(), e);
-			} catch (ClassNotFoundException e) {
-				m_log.warn(className + " is not poller class");
-				continue;
-			}
-			if (pollerConstructor == null) {
-				m_log.warn("action() : pollerConstructor is null");
-				continue;
-			}
-
-			// ポーラーの取得。
-			// 取得できたら、ポーリング実行。
-			VmPollerImplInterface poller = null;
-			try {
-				poller = (VmPollerImplInterface) pollerConstructor.newInstance();
-			} catch (Exception e) {
-				e.printStackTrace();
-			}
-			if (poller == null) {
-				m_log.warn("action() : poller is null");
-				continue;
-			}
-
-			String vmName = nodeInfo.getVmName();
-			m_log.debug("vmname : " + vmName);
-
-			String vmNodeType = nodeInfo.getVirtualizationNodeType();
-			m_log.debug("vmNodeType : " + vmNodeType);
-
-			// ホストノードから値を取得する
-			NodeInfo targetNodeInfo = null;
-			if(vmNodeType != null) {
-				if(vmNodeType.equals("host")) {
-					// ホストノードのパラメータを用いる
-					targetNodeInfo = nodeInfo;
-				} else if(vmNodeType.equals("guest")){
-					// ゲストノード用ポーリングパラメータを用いる
-					try {
-						targetNodeInfo = NodeProperty.getProperty(nodeInfo.getVmManagementNode());
-					} catch (FacilityNotFound e) {
-						m_log.warn("facility not found 3. FacilityId = " + m_targetFacilityId);
-						// ポーリングは実行しない
-						continue;
-					}
+			////
+			// 各種オプションでの監視用ポーラ取得箇所
+			// IPollerインターフェースを継承したポーラが、ポーラーのプロトコル名をキーにして事前にObjectSharingServiceに
+			// 登録されている場合、そのインスタンスを取り出して監視を実行する。
+			// 各種オプションのJARファイル内で、Plugin機構により登録されている前提。
+			// 2013年8月末時点で、VM・クラウドの2オプションで本機構を使用している
+			////
+			if(pollerProtocol != null){
+				
+				IPoller poller = null;
+				try {
+					poller = ObjectSharingService.objectRegistry().get(IPoller.class, pollerProtocol);
+				} catch (Exception e) {
+					m_log.warn("polling() : "
+							+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				}
+				// pollerが取得できない場合、未登録のポーリングメソッドなのでログだけ出してスルー
+				if (poller == null) {
+					m_log.warn("polling : unknown pollerProtocol. facilityId = " + nodeInfo.getFacilityId() + ", protocol = " + pollerProtocol);
+					continue;
+				}
+				// ポーラーの実体のメソッドを呼び出して、実際にポーリングを行う
+				// もし独自のオプション製品で、nodeinfoとpollingTarget以外のパラメタが必要な場合、
+				// 第3引数のObjectに突っ込むことで対応する。
+				// その場合は独自のオプション用にpollerProtocolの内容で分岐する必要がある。
+				// （できれば本体側に手を入れずにすむよう、第三引数は使わず、ポーラ内で情報を取ることが望ましいが・・・）
+				tmpDataTable = poller.polling(
+						nodeInfo,
+						pollingTarget,
+						null);
+				if (tmpDataTable != null) {
+					dataTable.putAll(tmpDataTable);
 				}
 			}
-
-			poller.init(pollerProtocol);
-			tmpDataTable = poller.polling(nodeInfo, targetNodeInfo,
-					pollingTargetMap.get(pollerProtocol));
-			dataTable.putAll(tmpDataTable);
 		}
+
 		return dataTable;
 	}
 
@@ -652,17 +563,16 @@ public class PollingController {
 		try {
 			nodeInfo = NodeProperty.getProperty(m_targetFacilityId);
 		} catch (FacilityNotFound e) {
-			m_log.warn("facility not found 4. FacilityId = " + m_targetFacilityId);
 			// ポーリングは実行しない
 			return dataTable;
 		}
 
 		if(nodeInfo == null) {
-			m_log.warn("facility not found 5. FacilityId = " + nodeInfo.getFacilityId());
+			m_log.info("facility not found 5. FacilityId = " + null);
 			// ポーリングは実行しない
 			return dataTable;
 		} else if (nodeInfo.getFacilityId() == null || "".equals(nodeInfo.getFacilityId())){
-			m_log.warn("invalid FacilityId. FacilityId = " + nodeInfo.getFacilityId());
+			m_log.info("invalid FacilityId. FacilityId = " + nodeInfo.getFacilityId());
 			// ポーリングは実行しない
 			return dataTable;
 		}
@@ -672,23 +582,6 @@ public class PollingController {
 		return dataTable;
 	}
 
-	protected SharedTable lookupSharedTable() throws NamingException{
-		try {
-			// 指定の値格納用テーブルが存在するか確認する
-			InitialContext ctx = new InitialContext();
-
-			Object obj = ctx.lookup(SHARED_TABLE_JNDI_NAME);
-
-			SharedTable table =
-				(SharedTable)PortableRemoteObject.narrow(obj, SharedTable.class);
-
-			return table;
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
-			throw e;
-		}
-	}
-
 	/**
 	 * ポーラグループ名を返します。
 	 * @return ポーラグループ名
