@@ -982,7 +982,7 @@ public class RepositoryControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh_ALL();
+					FacilityTreeCache.refresh();
 
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -1063,7 +1063,7 @@ public class RepositoryControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refreshInfo();
+					FacilityTreeCache.refresh();
 
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -1137,7 +1137,7 @@ public class RepositoryControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh_ALL();
+					FacilityTreeCache.refresh();
 
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -1374,7 +1374,7 @@ public class RepositoryControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh_ALL();
+					FacilityTreeCache.refresh();
 					
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -1452,7 +1452,7 @@ public class RepositoryControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refreshInfo();
+					FacilityTreeCache.refresh();
 
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -1525,7 +1525,7 @@ public class RepositoryControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refresh_ALL();
+					FacilityTreeCache.refresh();
 
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -1838,7 +1838,7 @@ public class RepositoryControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refreshTreeItem();
+					FacilityTreeCache.refresh();
 					
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
@@ -1964,7 +1964,7 @@ public class RepositoryControllerBean {
 					FacilitySelector.initCacheFacilityTree();
 					
 					// ファシリティツリー情報を更新する
-					FacilityTreeCache.refreshTreeItem();
+					FacilityTreeCache.refresh();
 					
 					// read-committedのため、commit後に外部コンポーネントに通知する
 					RepositoryManagerUtil.broadcastConfigured();
