@@ -22,13 +22,11 @@ import java.util.List;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.bean.PriorityConstant;
-import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
 import com.clustercontrol.poller.impl.SnmpPollerImpl;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.TableEntry;
-import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.apllog.AplLogger;
 
 /**
  * メモリのスワップアウト発生を確認する処理の実装クラス
@@ -37,23 +35,23 @@ public class RAMSwapOutMonitor extends SelfCheckMonitorBase {
 
 	private static Log m_log = LogFactory.getLog( RAMSwapOutMonitor.class );
 
-	private static final String monitorIdPrefix = "SYS_SWAPOUT";
-	private String monitorId = "";
-	private String application = "SELFCHECK (swap-out)";
+	public final String monitorId = "SYS_SWAPOUT";
+	public final String subKey = "";
+	public final String application = "SELFCHECK (swap-out)";
 
-	private long intervalMSec = 60000;
+	public final long intervalMSec;
 
-	private int snmpPort = 161;
-	private String snmpVersion = "2c";
-	private String snmpCommunity = "public";
-	private int snmpRetries = 0;
-	private int snmpTimeout = 3000;
+	public final int snmpPort;
+	public final String snmpVersion;
+	public final String snmpCommunity;
+	public final int snmpRetries;
+	public final int snmpTimeout;
 
-	private static final String SNMP_POLLING_IPADDRESS = "127.0.0.1";
-	private final String POLLING_TARGET_OID  = ".1.3.6.1.4.1.2021.11.63";
-	private final String RAW_SWAP_OUT_OUT_OID = ".1.3.6.1.4.1.2021.11.63.0";
+	public final String SNMP_POLLING_IPADDRESS = "127.0.0.1";
+	public final String POLLING_TARGET_OID  = ".1.3.6.1.4.1.2021.11.63";
+	public final String RAW_SWAP_OUT_OUT_OID = ".1.3.6.1.4.1.2021.11.63.0";
 
-	private static TableEntry previousMibValue = null;
+	private static volatile TableEntry previousMibValue = null;
 
 	/**
 	 * コンストラクタ
@@ -72,8 +70,6 @@ public class RAMSwapOutMonitor extends SelfCheckMonitorBase {
 		this.snmpCommunity = snmpCommunity;
 		this.snmpRetries = snmpRetries;
 		this.snmpTimeout = snmpTimeout;
-
-		this.monitorId = monitorIdPrefix;
 	}
 
 	/**
@@ -92,17 +88,24 @@ public class RAMSwapOutMonitor extends SelfCheckMonitorBase {
 		return monitorId;
 	}
 
+	/**
+	 * 監視項目subKey
+	 */
+	@Override
+	public String getSubKey() {
+		return subKey;
+	}
+
 	/**
 	 * スワップアウトの発生を確認する処理
 	 * @return 通知情報（アプリケーション名は未格納）
 	 */
 	@Override
-	public OutputBasicInfo execute() {
+	public void execute() {
 		/** ローカル変数 */
 		long swapOutSize = 0;
 		long lastUpdateTime = 0;
-
-		OutputBasicInfo notifyInfo = null;
+		boolean warn = true;
 
 		/** メイン処理 */
 		if (m_log.isDebugEnabled()) m_log.debug("monitoring swap-out.");
@@ -116,37 +119,29 @@ public class RAMSwapOutMonitor extends SelfCheckMonitorBase {
 		swapOutSize = getSwapOut();
 
 		if (swapOutSize < 0) {
-			if (m_log.isInfoEnabled())
-				m_log.info("skipped monitoring swap-out.");
+			m_log.info("skipped monitoring swap-out.");
+			return;
 		} else if (swapOutSize == 0) {
-			if (m_log.isDebugEnabled())
-				m_log.debug("swap-out blocks is none.");
-
-			// set result, but do not notify (priority == info)
-			notifyInfo = new OutputBasicInfo();
-			notifyInfo.setPluginId(PLUGIN_ID);
-			notifyInfo.setMonitorId(monitorId);
-			notifyInfo.setPriority(PriorityConstant.TYPE_INFO);
-		} else {
-			m_log.warn("swap-out occurred. (swapOutSize=" + swapOutSize + ")");
-			notifyInfo = new OutputBasicInfo();
-
-			String[] msgAttr1 = { new Long(swapOutSize).toString() };
-			String[] msgAttr2 = { new Long(swapOutSize).toString(), String.format("%1$tY-%1$tm-%1$td %1$tH:%1$tM:%1$tS", new Date(lastUpdateTime)) };
-
-			notifyInfo.setPluginId(PLUGIN_ID);
-			notifyInfo.setMonitorId(monitorId);
-			notifyInfo.setApplication(application);
-			notifyInfo.setMessageId("001");
-			notifyInfo.setMessage(Messages.getString("message.selfcheck.notify.ram.swapout.failure.msg", msgAttr1));
-			notifyInfo.setMessageOrg(Messages.getString("message.selfcheck.notify.ram.swapout.failure.origmsg", msgAttr2));
-			notifyInfo.setFacilityId(FACILITY_ID);
-			notifyInfo.setScopeText(FACILITY_TEXT);
-			notifyInfo.setPriority(PriorityConstant.TYPE_WARNING);
-			notifyInfo.setGenerationDate(new Date().getTime());
+			m_log.debug("swap-out does not occurred.");
+			warn = false;
 		}
 
-		return notifyInfo;
+		if (warn) {
+			m_log.info("swap-out occurred. (swapOutSize=" + swapOutSize + ")");
+		}
+		if (!isNotify(warn)) {
+			return;
+		}
+		String[] msgAttr1 = { new Long(swapOutSize).toString() };
+		AplLogger aplLogger = new AplLogger(PLUGIN_ID, APL_ID);
+		aplLogger.put(MESSAGE_ID, "005", msgAttr1,
+				"ram swap-out(" +
+						swapOutSize +
+						" [blocks]) occurred since " +
+						String.format("%1$tY-%1$tm-%1$td %1$tH:%1$tM:%1$tS", new Date(lastUpdateTime)) +
+				".");
+
+		return;
 	}
 
 	/**
