@@ -184,7 +184,7 @@ if [ -f ${AGENT_PROPERTIES} ]; then
 
     TMP_KEY="${user}.public.key=`cat ${user_home}/.ssh/id_rsa.pub`"
     if [ `${GREP_PROC} "${TMP_KEY}" ${AGENT_PROPERTIES} | wc -l` = 0 ]; then 
-        echo $TMP_KEY >> ${AGENT_PROPERTIES}
+        echo -n $TMP_KEY >> ${AGENT_PROPERTIES}
     fi
 
 else # When the Hinemos agent is not installed.
@@ -232,7 +232,7 @@ $EXPECT_PROC -c "
     set timeout 1
     spawn -noecho $SSH_PROC -n ${ip_address} -l root \"
         if \[ \`${GREP_PROC} ${user}.authorized.keys.path=${user_home}/.ssh/authorized_keys ${AGENT_PROPERTIES} | wc -l\` = 0 \]; then
-            echo ${user}.authorized.keys.path=${user_home}/.ssh/authorized_keys >> ${AGENT_PROPERTIES}
+            echo -n ${user}.authorized.keys.path=${user_home}/.ssh/authorized_keys >> ${AGENT_PROPERTIES}
         fi        
     \"
     expect root
